@@ -204,17 +204,17 @@ getRMS = function(x,
 
   # calculate RMS per frame
   myseq = seq(1, max(1, (audio$ls - windowLength_points)), step_points)
-  r = apply(as.matrix(myseq), 1, function(x) {
+  r = vapply(myseq, function(x) {
     sqrt(mean(audio$sound[x:(windowLength_points + x - 1)] ^ 2))
-  })
+  }, numeric(1))
   names(r) = myseq / audio$samplingRate * 1000 + windowLength / 2 + audio$timeShift * 1000
   if (normalize) r = r / audio$scale
 
   # same for the right channel
   if (!is.null(audio$right) & stereo %in% c('average', 'both')) {
-    r2 = apply(as.matrix(myseq), 1, function(x) {
+    r2 = vapply(myseq, function(x) {
       sqrt(mean(audio$right[x:(windowLength_points + x - 1)] ^ 2))
-    })
+    }, numeric(1))
     names(r2) = names(r)
     if (normalize) r2 = r2 / audio$scale
   }
@@ -271,7 +271,7 @@ getRMS = function(x,
     }
     if (is.character(audio$savePlots)) dev.off()
   }
-  return(r)
+  r
 }
 
 
@@ -312,10 +312,10 @@ getRMS = function(x,
 #' @examples
 #' \dontrun{
 #' # put a few short audio files in a folder, eg '~/Downloads/temp'
-#' getRMS('~/Downloads/temp2', summaryFun = 'mean')$summary  # different
-#' normalizeFolder('~/Downloads/temp2', type = 'rms', summaryFun = 'mean',
-#'   saveAudio = '~/Downloads/temp2/normalized')
-#' getRMS('~/Downloads/temp2/normalized', summaryFun = 'mean')$summary  # same
+#' getRMS('~/Downloads/temp', summaryFun = 'mean')$summary  # different
+#' normalizeFolder('~/Downloads/temp', type = 'rms', summaryFun = 'mean',
+#'   saveAudio = '~/Downloads/temp/normalized')
+#' getRMS('~/Downloads/temp/normalized', summaryFun = 'mean')$summary  # same
 #' # If the saved audio files are treated as stereo with one channel missing,
 #' # try reconverting with ffmpeg (saving is handled by tuneR::writeWave)
 #' }
@@ -349,11 +349,14 @@ normalizeFolder = function(
   for (i in 1:n) {
     ext = substr(filenames[i], (nchar(filenames[i]) - 2), nchar(filenames[i]))
     if (ext %in% c('wav', 'WAV')) {
-      files[[i]] = tuneR::readWave(filenames[i])
+      files[[i]] = try(tuneR::readWave(filenames[i]))
     } else if (ext %in% c('mp3', 'MP3')) {
-      files[[i]] = tuneR::readMP3(filenames[i])
+      files[[i]] = try(tuneR::readMP3(filenames[i]))
     } else {
-      stop('Input not recognized')
+      message(paste('Error processing file', filenames[i]))
+    }
+    if (inherits(files[[i]], 'try-error')) {
+      message(paste('Error processing file', filenames[i]))
     }
   }
 
@@ -362,9 +365,11 @@ normalizeFolder = function(
   # for either peak or RMS normalization, start by peak normalization to maxAmp dB
   level = 10 ^ (maxAmp / 20)
   for (i in 1:n) {
-    files[[i]] = tuneR::normalize(files[[i]],
-                                  unit = as.character(files[[i]]@bit),
-                                  rescale = TRUE, level = level)
+    if (!inherits(files[[i]], 'try-error'))
+      files[[i]] = tuneR::normalize(
+        files[[i]],
+        unit = as.character(files[[i]]@bit),
+        rescale = TRUE, level = level)
   }
 
   # for RMS- or loudness-normalization, perform additional steps
@@ -373,28 +378,32 @@ normalizeFolder = function(
     if (type == 'rms') {
       for (i in 1:n) {
         # calculate the RMS amplitude of each file
-        perSound[[i]] = getRMS(files[[i]],
-                               windowLength = windowLength,
-                               step = step,
-                               overlap = overlap,
-                               scale = 2^(files[[i]]@bit - 1),
-                               killDC = killDC,
-                               windowDC = windowDC,
-                               plot = FALSE)$detailed
+        if (!inherits(files[[i]], 'try-error'))
+          perSound[[i]] = getRMS(
+            files[[i]],
+            windowLength = windowLength,
+            step = step,
+            overlap = overlap,
+            scale = 2^(files[[i]]@bit - 1),
+            killDC = killDC,
+            windowDC = windowDC,
+            plot = FALSE)$detailed
       }
     } else if (type == 'loudness') {
       for (i in 1:n) {
         # estimate subjective loudness of each file
-        perSound[[i]] = getLoudness(files[[i]],
-                                    scale = 2^(files[[i]]@bit - 1),
-                                    windowLength = windowLength,
-                                    step = step,
-                                    plot = FALSE)$loudness
+        if (!inherits(files[[i]], 'try-error'))
+          perSound[[i]] = getLoudness(
+            files[[i]],
+            scale = 2^(files[[i]]@bit - 1),
+            windowLength = windowLength,
+            step = step,
+            plot = FALSE)$loudness
       }
     }
 
     # summary measure per file
-    summaryPerSound = unlist(lapply(perSound, summaryFun))
+    summaryPerSound = sapply(perSound, summaryFun)
     names(summaryPerSound) = basename(filenames)
 
     # find the quietest file
@@ -403,7 +412,7 @@ normalizeFolder = function(
     # the quietest file is untouched, but all others are rescaled to have the
     # same RMS/loudness as the quietest one
     for (i in 1:n) {
-      if (i != ref) {
+      if (!inherits(files[[i]], 'try-error') & i != ref) {
         if (type == 'rms') {
           rescale = summaryPerSound[ref] / summaryPerSound[i]
         } else if (type == 'loudness') {
@@ -420,11 +429,13 @@ normalizeFolder = function(
     print('Saving...')
     if (!dir.exists(saveAudio)) dir.create(saveAudio)
     for (i in 1:n) {
-      file_wo_ext = sub("([^.]+)\\.[[:alnum:]]+$", "\\1", basename(filenames[i]))
-      tuneR::writeWave(
-        files[[i]],
-        filename = paste0(saveAudio, '/', file_wo_ext, '.wav')
-      )
+      if (!inherits(files[[i]], 'try-error')) {
+        file_wo_ext = sub("([^.]+)\\.[[:alnum:]]+$", "\\1", basename(filenames[i]))
+        tuneR::writeWave(
+          files[[i]],
+          filename = paste0(saveAudio, '/', file_wo_ext, '.wav')
+        )
+      }
     }
   }
 
@@ -492,10 +503,10 @@ normalizeFolder = function(
 #' s3 = flatEnv(s1, 16000, plot = TRUE, windowLength_points = 50, killDC = TRUE)
 #'
 #' # Compress and save all audio files in a folder
-#' s4 = flatEnv('~/Downloads/temp2',
+#' s4 = flatEnv('~/Downloads/temp',
 #'              method = 'peak', compression = .5,
-#'              saveAudio = '~/Downloads/temp2/compressed',
-#'              savePlots = '~/Downloads/temp2/compressed',
+#'              saveAudio = '~/Downloads/temp/compressed',
+#'              savePlots = '~/Downloads/temp/compressed',
 #'              col = 'green', lwd = 5)
 #' osc(s4[[1]])
 #' }
@@ -646,7 +657,7 @@ compressor = flatEnv
     writeAudio(soundFlat, audio = audio, filename = filename)
   }
 
-  return(soundFlat)
+  soundFlat
 }
 
 
@@ -770,194 +781,7 @@ transplantEnv = function(donor,
 
     par(mfrow = op)
   }
-  invisible(out)
-}
-
-
-#' Add amplitude modulation
-#'
-#' Adds sinusoidal or logistic amplitude modulation to a sound. This produces
-#' additional harmonics in the spectrum at ±am_freq around each original
-#' harmonic and makes the sound rough. The optimal frequency for creating a
-#' perception of roughness is ~70 Hz (Fastl & Zwicker "Psychoacoustics").
-#' Sinusoidal AM creates a single pair of new harmonics, while non-sinusoidal AM
-#' creates more extra harmonics (see examples).
-#' @inheritParams spectrogram
-#' @inheritParams soundgen
-#' @param play if TRUE, plays the processed audio
-#' @param saveAudio full (!) path to folder for saving the processed audio; NULL
-#'   = don't save, '' = same as input folder (NB: overwrites the originals!)
-#' @param plot if TRUE, plots the amplitude modulation
-#' @export
-#' @examples
-#' sound1 = soundgen(pitch = c(200, 300), addSilence = 0)
-#' s1 = addAM(sound1, 16000, amDep = c(0, 50, 0), amFreq = 75, plot = TRUE)
-#' # playme(s1)
-#' \dontrun{
-#' # Parameters can be specified as in the soundgen() function, eg:
-#' s2 = addAM(sound1, 16000,
-#'          amDep = list(time = c(0, 50, 52, 200, 201, 300),
-#'                       value = c(0, 0, 35, 25, 0, 0)),
-#'          plot = TRUE, play = TRUE)
-#'
-#' # Sinusoidal AM produces exactly 2 extra harmonics at ±am_freq
-#' # around each f0 harmonic:
-#' s3 = addAM(sound1, 16000, amDep = 30, amFreq = c(50, 80),
-#'            amType = 'sine', plot = TRUE, play = TRUE)
-#' spectrogram(s3, 16000, windowLength = 150, ylim = c(0, 2))
-#'
-#' # Non-sinusoidal AM produces multiple new harmonics,
-#' # which can resemble subharmonics...
-#' s4 = addAM(sound1, 16000, amDep = 70, amFreq = 50, amShape = -1,
-#'            plot = TRUE, play = TRUE)
-#' spectrogram(s4, 16000, windowLength = 150, ylim = c(0, 2))
-#'
-#' # ...but more often look like sidebands
-#' sound3 = soundgen(sylLen = 600, pitch = c(800, 1300, 1100), addSilence = 0)
-#' s5 = addAM(sound3, 16000, amDep = c(0, 30, 100, 40, 0),
-#'            amFreq = 105, amShape = -.3,
-#'            plot = TRUE, play = TRUE)
-#' spectrogram(s5, 16000, ylim = c(0, 5))
-#'
-#' # Feel free to add AM stochastically:
-#' s6 = addAM(sound1, 16000,
-#'            amDep = rnorm(10, 40, 20), amFreq = rnorm(20, 70, 20),
-#'            plot = TRUE, play = TRUE)
-#' spectrogram(s6, 16000, windowLength = 150, ylim = c(0, 2))
-#'
-#' # If am_freq is locked to an integer ratio of f0, we can get subharmonics
-#' # For ex., here is with pitch 400-600-400 Hz (soundgen interpolates pitch
-#' # on a log scale and am_freq on a linear scale, so we align them by extracting
-#' # a long contour on a log scale for both)
-#' con = getSmoothContour(anchors = c(400, 600, 400),
-#'                        len = 20, thisIsPitch = TRUE)
-#' s = soundgen(sylLen = 1500, pitch = con, amFreq = con/3, amDep = 30,
-#'              plot = TRUE, play = TRUE, ylim = c(0, 3))
-#'
-#' # Process all files in a folder and save the modified audio
-#' addAM('~/Downloads/temp', saveAudio = '~/Downloads/temp/AM',
-#'       amFreq = 70, amDep = c(0, 50))
-#' }
-addAM = function(x,
-                 samplingRate = NULL,
-                 amDep = 25,
-                 amFreq = 30,
-                 amType = c('logistic', 'sine')[1],
-                 amShape = 0,
-                 invalidArgAction = c('adjust', 'abort', 'ignore')[1],
-                 plot = FALSE,
-                 play = FALSE,
-                 saveAudio = NULL,
-                 reportEvery = NULL,
-                 cores = 1) {
-  # check the format of AM pars
-  anchors = c('amDep', 'amFreq', 'amShape')
-  for (anchor in anchors) {
-    assign(anchor, reformatAnchors(get(anchor)))
-  }
-  rm('anchor', 'anchors')
-
-  # match args
-  myPars = c(as.list(environment()))
-  # exclude some args
-  myPars = myPars[!names(myPars) %in% c(
-    'x', 'samplingRate', 'reportEvery', 'cores', 'saveAudio')]
-  pa = processAudio(x,
-                    samplingRate = samplingRate,
-                    saveAudio = saveAudio,
-                    funToCall = '.addAM',
-                    myPars = myPars,
-                    reportEvery = reportEvery,
-                    cores = cores)
-  # prepare output
-  if (pa$input$n == 1) {
-    result = pa$result[[1]]
-  } else {
-    result = pa$result
-  }
-  invisible(result)
-}
-
-
-#' Add AM to a sound
-#'
-#' Internal soundgen function, see \code{\link{addAM}}.
-#'
-#' @inheritParams addAM
-#' @param audio a list returned by \code{readAudio}
-#' @keywords internal
-.addAM = function(
-    audio,
-    amDep = 25,
-    amFreq = 30,
-    amType = c('logistic', 'sine')[1],
-    amShape = 0,
-    invalidArgAction = c('adjust', 'abort', 'ignore')[1],
-    plot = FALSE,
-    play = FALSE
-) {
-  # vectorize
-  amPar_vect = c('amDep', 'amFreq', 'amShape')
-  # just to get rid of of NOTE on CRAN:
-  amDep_vector = amFreq_vector = amShape_vector = vector()
-  for (p in amPar_vect) {
-    p_unique_value = unique(get(p)$value)
-    if (length(p_unique_value) > 1) {
-      if (invalidArgAction == 'ignore') {
-        valueFloor_p = valueCeiling_p = NULL
-      } else {
-        valueFloor_p = permittedValues[p, 'low']
-        valueCeiling_p = permittedValues[p, 'high']
-      }
-      p_vectorized = getSmoothContour(
-        anchors = get(p),
-        len = audio$ls,
-        interpol = 'approx',
-        valueFloor = valueFloor_p,
-        valueCeiling = valueCeiling_p
-      )
-      # plot(p_vectorized, type = 'l')
-      assign(paste0(p, '_vector'), p_vectorized)
-    } else {
-      assign(paste0(p, '_vector'), p_unique_value)
-    }
-  }
-
-  # prepare am vector
-  if (amType == 'sine') {
-    if (length(amFreq_vector) == 1) {
-      int = amFreq_vector * (1:audio$ls)
-    } else {
-      int = cumsum(amFreq_vector)
-    }
-    sig = .5 + .5 * cos(2 * pi * int / audio$samplingRate)
-  } else {
-    sig = getSigmoid(len = audio$ls,
-                     samplingRate = audio$samplingRate,
-                     freq = amFreq_vector,
-                     shape = amShape_vector)
-  }
-  # plot(sig, type = 'l')
-  # sig is on a scale [0, 1]
-  am = 1 - sig * amDep_vector / 100
-  sound_am = audio$sound * am
-
-  if (plot) {
-    .osc(list(sound = am,
-              samplingRate = audio$samplingRate,
-              ls = length(am)),
-         main = 'Amplitude modulation',
-         xlab = 'Time, ms',
-         ylab = '',
-         ylim = c(0, 1),
-         midline = FALSE)
-  }
-  if (play) playme(sound_am, audio$samplingRate)
-  if (is.character(audio$saveAudio)) {
-    filename = paste0(audio$saveAudio, '/', audio$filename_noExt, '.wav')
-    writeAudio(sound_am, audio = audio, filename = filename)
-  }
-  invisible(sound_am)
+  out
 }
 
 
@@ -1039,7 +863,7 @@ getEnv = function(
   # remove the zero-padded regions
   env = env[(windowLength_points + 1):(len - windowLength_points)]
   # osc(env)
-  return(env)
+  env
 }
 
 
@@ -1096,5 +920,5 @@ killDC = function(sound,
     points(rep(0, length(sound)), type = 'l', col = 'blue')
     par(mfrow = op)
   }
-  return(soundNorm)
+  soundNorm
 }
