@@ -141,207 +141,6 @@ convert_sec_to_hms = function(time_s, digits = 0) {
 }
 
 
-#' Convert Hz to semitones
-#'
-#' Converts from Hz to semitones above C-5 (~0.5109875 Hz) or another reference
-#' frequency. This may not seem very useful, but note that this gives us a nice
-#' logarithmic scale for generating natural pitch transitions.
-#'
-#' @seealso \code{\link{semitonesToHz}} \code{\link{HzToNotes}}
-#'
-#' @param h vector or matrix of frequencies (Hz)
-#' @param ref frequency of the reference value (defaults to C-5, 0.51 Hz)
-#' @export
-#' @examples
-#' s = HzToSemitones(c(440, 293, 115))
-#' # to convert to musical notation
-#' notesDict$note[1 + round(s)]
-#' # note the "1 +": semitones ABOVE C-5, i.e. notesDict[1, ] is C-5
-#'
-#' # Any reference tone can be specified. For ex., for semitones above C0, use:
-#' HzToSemitones(440, ref = 16.35)
-#' # TIP: see notesDict for a table of Hz frequencies to musical notation
-HzToSemitones = function(h, ref = 0.5109875) {
-  log2(h / ref) * 12
-}
-
-#' Convert semitones to Hz
-#'
-#' Converts from semitones above C-5 (~0.5109875 Hz) or another reference
-#' frequency to Hz. See \code{\link{HzToSemitones}}
-#'
-#' @seealso \code{\link{HzToSemitones}}
-#'
-#' @param s vector or matrix of frequencies (semitones above C0)
-#' @param ref frequency of the reference value (defaults to C-5, 0.51 Hz)
-#' @export
-#' @examples
-#' semitonesToHz(c(117, 105, 60))
-semitonesToHz = function(s, ref = 0.5109875) {
-  ref * 2 ^ (s / 12)
-}
-
-
-#' Convert Hz to notes
-#'
-#' Converts from Hz to musical notation like A4 - note A of the fourth octave
-#' above C0 (16.35 Hz).
-#'
-#' @seealso \code{\link{notesToHz}} \code{\link{HzToSemitones}}
-#'
-#' @param h vector or matrix of frequencies (Hz)
-#' @param showCents if TRUE, show cents to the nearest notes (cent = 1/100 of a
-#'   semitone)
-#' @param A4 frequency of note A in the fourth octave (modern standard ISO 16 or
-#'   concert pitch = 440 Hz)
-#' @export
-#' @examples
-#' HzToNotes(c(440, 293, 115, 16.35, 4))
-#'
-#' HzToNotes(c(440, 415, 80, 81), showCents = TRUE)
-#' # 80 Hz is almost exactly midway (+49 cents) between D#2 and E2
-#'
-#' # Baroque tuning A415, half a semitone flat relative to concert pitch A440
-#' HzToNotes(c(440, 415, 16.35), A4 = 415)
-HzToNotes = function(h, showCents = FALSE, A4 = 440) {
-  ref = A4 / 861.0779
-  # C4 is 9 semitones below A4 (2^(9/12) * 512 = 861.0779), then another 9 octaves
-  # down to C-5 in notesDict
-  sem = log2(h / ref) * 12
-  round_sem = round(sem)
-  nearest_note = soundgen::notesDict$note[1 + round_sem]
-  if (showCents) {
-    cents = paste0(' ', as.character(round((sem - round_sem) * 100)))
-    cents[cents == ' 0'] = ''
-    nearest_note = paste0(nearest_note, cents)
-  }
-  nearest_note
-}
-
-
-#' Convert notes to Hz
-#'
-#' Converts to Hz from musical notation like A4 - note A of the fourth octave
-#' above C0 (16.35 Hz).
-#'
-#' @seealso \code{\link{HzToNotes}} \code{\link{HzToSemitones}}
-#'
-#' @param n vector or matrix of notes
-#' @param A4 frequency of note A in the fourth octave (modern standard ISO 16 or
-#'   concert pitch = 440 Hz)
-#' @export
-#' @examples
-#' notesToHz(c("A4", "D4", "A#2", "C0", "C-2"))
-#'
-#' # Baroque tuning A415, half a semitone flat relative to concert pitch A440
-#' notesToHz(c("A4", "D4", "A#2", "C0", "C-2"), A4 = 415)
-notesToHz = function(n, A4 = 440) {
-  soundgen::notesDict$freq[match(n, soundgen::notesDict$note)] * A4 / 440
-}
-
-
-#' Convert Hz to ERB rate
-#'
-#' Converts from Hz to the number of Equivalent Rectangular Bandwidths (ERBs)
-#' below input frequency. See https://www2.ling.su.se/staff/hartmut/bark.htm and
-#' https://en.wikipedia.org/wiki/Equivalent_rectangular_bandwidth
-#'
-#' @seealso \code{\link{ERBToHz}} \code{\link{HzToSemitones}}
-#'   \code{\link{HzToNotes}}
-#'
-#' @param h vector or matrix of frequencies (Hz)
-#' @param method approximation to use
-#' @export
-#' @examples
-#' HzToERB(c(-20, 20, 100, 440, 1000, NA))
-#'
-#' f = 20:20000
-#' erb_lin = HzToERB(f, 'linear')
-#' erb_quadratic = HzToERB(f, 'quadratic')
-#' plot(f, erb_lin, log = 'x', type = 'l')
-#' points(f, erb_quadratic, col = 'blue', type = 'l')
-#'
-#' # compare with the bark scale:
-#' barks = tuneR::hz2bark(f)
-#' points(f, barks / max(barks) * max(erb_lin),
-#'   col = 'red', type = 'l', lty = 2)
-HzToERB = function(h,
-                   method = c('linear', 'quadratic')[1]) {
-  if (method == 'linear') {
-    erb = 21.4 * log10(1 + .00437 * h)
-  } else if (method == 'quadratic') {
-    # erb = 11.17 * log( (h + 312) / (h + 14675)) + 43
-    erb = 11.17268 * log(1 + (46.06538 * h) / (h + 14678.49))
-  }
-  erb
-}
-
-
-#' Convert Hz to ERB rate
-#'
-#' Converts from Hz to the number of Equivalent Rectangular Bandwidths (ERBs)
-#' below input frequency. See https://www2.ling.su.se/staff/hartmut/bark.htm and
-#' https://en.wikipedia.org/wiki/Equivalent_rectangular_bandwidth
-#'
-#' @seealso \code{\link{HzToERB}} \code{\link{HzToSemitones}}
-#'   \code{\link{HzToNotes}}
-#'
-#' @param e vector or matrix of frequencies in ERB rate
-#' @param method approximation to use
-#' @export
-#' @examples
-#' freqs_Hz = c(-20, 20, 100, 440, 1000, 20000, NA)
-#' e_lin = HzToERB(freqs_Hz, 'linear')
-#' ERBToHz(e_lin, 'linear')
-#'
-#' e_quad = HzToERB(freqs_Hz, 'quadratic')
-#' ERBToHz(e_quad, 'quadratic')
-ERBToHz = function(e,
-                   method = c('linear', 'quadratic')[1]) {
-  if (method == 'linear') {
-    h = (10 ^ (e / 21.4) - 1) / .00437
-  } else if (method == 'quadratic') {
-    h = 676170.4 / (47.06538 - exp(e * 0.08950404)) - 14678.49
-  }
-  h
-}
-
-
-#' Hz to mel
-#'
-#' Internal soundgen function: a temporary fix needed because tuneR::hz2mel
-#' doesn't accept NAs or vectors.
-#' @param f frequency, Hz
-#' @param htk algrithm
-#' @keywords internal
-#' @examples
-#' soundgen:::hz2mel(c(440, 220, NA))
-#' freq = 1:10000
-#' plot(freq, soundgen:::hz2mel(freq), type = 'l')
-hz2mel = function(f, htk = FALSE) {
-  # if (!is.numeric(f) || f < 0)
-  #     stop("frequencies have to be non-negative")
-  idx_nonFinite = which(!is.finite(f))
-  f[idx_nonFinite] = 0
-  if (htk) {
-    z = 2595 * log10(1 + f/700)
-  }
-  else {
-    f_0 = 0
-    f_sp = 200/3
-    brkfrq = 1000
-    brkpt = (brkfrq - f_0) / f_sp
-    logstep = exp(log(6.4) / 27)
-    linpts = (f < brkfrq)
-    z = 0 * f
-    z[linpts] = (f[linpts] - f_0) / f_sp
-    z[!linpts] = brkpt + (log(f[!linpts] / brkfrq)) / log(logstep)
-  }
-  z[idx_nonFinite] = NA
-  z
-}
-
-
 #' Find peaks
 #'
 #' A bare-bones, very fast function to find local maxima (peaks) in a numeric
@@ -403,15 +202,6 @@ to_dB = function(x) {
   10 * log10(x / (1 - x))
 }
 
-#' List depth
-#'
-#' Internal soundgen function
-#'
-#' Returns the depth of list structure. See https://stackoverflow.com/questions/13432863/determine-level-of-nesting-in-r
-#' @param x any R object
-#' @keywords internal
-listDepth = function(x) ifelse(is.list(x), 1L + max(sapply(x, listDepth)), 0L)
-
 
 #' Normalize 0 to 1
 #'
